@@ -4,7 +4,7 @@ package Random::Skew;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 our $GRAIN = 72; # default
 sub GRAIN {
@@ -299,7 +299,7 @@ random data.
 
 Sets up the L<Random::Skew> C<$rs> object. The C<%weightings> determine
 how likely any particular item is going to be the value generated by
-C<<$rs->item()>>.
+C<< $rs->item() >>.
 
   my %majors = (
     PSYCH => 2135,
@@ -343,13 +343,15 @@ at once, meaning that a scale multiplier is applied to reduce the number
 of instances of each value to a "sane" number, the C<Random::Skew::ROUNDING>
 value is added before truncating to an int.
 
-Example: Weights 5, 4, 3 would all fit in 12 buckets. If our C<GRAIN> is 10,
-then we multiply them by 10/12 to get:
+Example: Weights 5, 4, 3 would all fit nicely into 12 buckets. If our
+C<GRAIN> is 10, then we multiply them by 10/12 to get:
+
   5 => 5*10/12 => 4.16
   4 => 4*10/12 => 3.33
   3 => 3*10/12 => 2.5
-With C<ROUNDING> of 0.0, this would result in buckets of size 4, 3, 2.
-With C<ROUNDING> of 0.5, we would get 4.66=>4, 3.73=>3, 3.0=>3.
+
+With C<ROUNDING> of 0.0, we truncate to integers, so this would result in buckets
+of size C<4, 3, 2>. With C<ROUNDING> of 0.5, we would get C<< 4.66=>4, 3.83=>3, 3.0=>3 >>.
 
 =back
 
@@ -413,7 +415,7 @@ To ameliorate rounding issues, see L<Random::Skew::Test> for how to
 explore different values of C<$Random::Skew::GRAIN> and
 C<$Rounding::Skew::ROUNDING>.
 
-=head1 METHODOLOGY
+=head2 METHODOLOGY
 
 Representing weightings that don't have a lot of variation, is a
 piece of cake.
@@ -517,7 +519,7 @@ C<$Random::Skel::GRAIN> works best, and for others a LARGE value
 does better. See L<Random::Skew::Test> for how to explore various
 values of C<$Random::Skew::GRAIN> to best fit your data.
 
-=head1 CAVEATS
+=head2 CAVEATS
 
 The value of C<$Random::Skew::GRAIN> can have a significant
 impact on how faithful the results are to your original weighting
